# aiofoam

[![Documentation](https://img.shields.io/readthedocs/aiofoam)](https://aiofoam.readthedocs.io/)
[![CI](https://github.com/gerlero/aiofoam/actions/workflows/ci.yml/badge.svg)](https://github.com/gerlero/aiofoam/actions/workflows/ci.yml)
[![Codecov](https://codecov.io/gh/gerlero/aiofoam/branch/main/graph/badge.svg)](https://codecov.io/gh/gerlero/aiofoam)
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![PyPI](https://img.shields.io/pypi/v/aiofoam)](https://pypi.org/project/aiofoam/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/aiofoam)](https://pypi.org/project/aiofoam/)


**aiofoam** provides an asynchronous ([`asyncio`](https://docs.python.org/3/library/asyncio.html)-based) API for running [OpenFOAM](https://www.openfoam.com) cases from Python.

Install with [pip](https://pypi.org/project/pip/):

```bash
pip install aiofoam
```

For more information, check out the [documentation](https://aiofoam.readthedocs.io/).
